Module bundle

Module bundle 

Structs

InMemoryBundleReader
In-memory reader for synthetic or cached bundles.
InMemoryBundleSources
A builder for creating bundles with multiple files
PendingFile
A file that is pending to be added to a bundle

Traits

BundleDecode
Trait for decoding data from a bundle of files
BundleEncode
Trait for encoding data into a bundle of files
BundleSink
Trait for writing files to a bundle
BundleSource
Trait for reading files from a bundle

Functions

normalize_bundle_path
Normalize a path within a bundle (use forward slashes, remove leading slash)