BurnCentralError

Enum BurnCentralError 

pub enum BurnCentralError {
    InvalidExperimentPath(String),
    InvalidProjectPath(String),
    InvalidExperimentNumber(String),
    InvalidModelPath(String),
    Client {
        context: String,
        source: ClientError,
    },
    ExperimentTracker(ExperimentTrackerError),
    Unauthenticated,
    Io(Error),
    Internal(String),
}
Errors that can occur during when using the BurnCentral client.

Those errors should be handled by the user of this library. If he want to implement fallback behavior or retry logic.

Variants



InvalidExperimentPath(String)

Input validation errors



InvalidProjectPath(String)

This error occurs when the provided project path is invalid. It is a input validation errors. No API call has been made yet.



InvalidExperimentNumber(String)

This error occurs when the provided experiment number is invalid. It is a input validation errors. No API call has been made yet.



InvalidModelPath(String)

This error occurs when the provided model path is invalid. It is a input validation errors. No API call has been made yet.



Client

Represents an error related to client operations.

This error variant is used to encapsulate client-specific errors along with additional context and the underlying source error for more detailed debugging.

Fields

  • context (String): A description or additional information about the client error context.
  • source (ClientError): The underlying source of the client error, providing more details about the cause.

Fields

context: String


ExperimentTracker(ExperimentTrackerError)

Represents an error related to the experiment tracker. Those errors are coming from the websocket connection that open when starting an experiment run.



Unauthenticated

Error that should be used when the user is not logged in but tries to perform an operation that requires authentication.



Io(Error)

Error that should be used when the client performs operations that can fail due to IO issues.



Internal(String)

Error that should be used when the client encounters an error that is not specifically handled.