Structs
- InMemory
Bundle Reader - In-memory reader for synthetic or cached bundles.
- InMemory
Bundle Sources - A builder for creating bundles with multiple files
- Pending
File - A file that is pending to be added to a bundle
Traits
- Bundle
Decode - Trait for decoding data from a bundle of files
- Bundle
Encode - Trait for encoding data into a bundle of files
- Bundle
Sink - Trait for writing files to a bundle
- Bundle
Source - Trait for reading files from a bundle
Functions
- normalize_
bundle_ path - Normalize a path within a bundle (use forward slashes, remove leading slash)