pub enum BurnCentralError {
InvalidExperimentPath(String),
InvalidProjectPath(String),
InvalidExperimentNumber(String),
InvalidModelPath(String),
Client {
context: String,
source: ClientError,
},
ExperimentTracker(ExperimentTrackerError),
Unauthenticated,
Io(Error),
Internal(String),
}Variants
InvalidExperimentPath(String)
InvalidProjectPath(String)
InvalidExperimentNumber(String)
InvalidModelPath(String)
Client
Represents an error related to client operations.
This error variant is used to encapsulate client-specific errors along with additional context and the underlying source error for more detailed debugging.
Fields
context(String): A description or additional information about the client error context.source(ClientError): The underlying source of the client error, providing more details about the cause.
ExperimentTracker(ExperimentTrackerError)
Represents an error related to the experiment tracker.
Unauthenticated
Error that should be used when the user is not logged in but tries to perform an operation that requires authentication.
Io(Error)
Error that should be used when the client performs operations that can fail due to IO issues.
Internal(String)
Error that should be used when the client encounters an error that is not specifically handled.